/* Copyright 2014 Bernhard R. Fischer.
 *
 * This file is part of DChat.
 *
 * DChat is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * DChat is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DChat. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONTACTS_H
#define CONTACTS_H

#include <sys/socket.h>
#include <netinet/in.h>
#include <pthread.h>

#define MAX_CONTACTS 50
#define RAW_BUF_LEN 32768


typedef struct contact
{
   int fd;                       //<! file descriptor of TCP session (0 if unused)
   struct sockaddr_storage remote_addr;

   const
   struct sockaddr *local_addr;  //! pointer to local socket address
   
   char rbuf[RAW_BUF_LEN];       //!< framing input buffer
   char wbuf[RAW_BUF_LEN];       //!< output buffer
   int rlen;                     //!< number of bytes in input buffer
   int wlen;                     //!< number of bytes in output buffer
   uint16_t port;                //!< remote port number

   char hostname[256];           //!< hostname of contact (if SOCKS4a is in use)
} contact_t;


typedef struct contact_list
{
   pthread_mutex_t cl_mx;           //!< mutex for contact list
   contact_t contact[MAX_CONTACTS]; //!< array of contacts
} contact_list_t;


int lock_contacts(contact_list_t *);
int unlock_contacts(contact_list_t *);
int add_contact(contact_list_t *, int , const struct sockaddr *, const struct sockaddr *, const char *);


#endif

