/* Copyright 2014 Bernhard R. Fischer.
 *
 * This file is part of DChat.
 *
 * DChat is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * DChat is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DChat. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CQUEUE_H
#define CQUEUE_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <sys/socket.h>
#include <pthread.h>


// FIXME: This should be defined outside of this header
typedef struct command
{
   struct sockaddr_storage ss;
   char hostname[256];
   int port;
} command_t;

typedef struct qmsg
{
   int status;       //!< status of message
   int fd;           //!< socket to connect
   command_t command;
} qmsg_t;

typedef struct queue
{
   qmsg_t *queue;    //!< dynamic area
   int cnt;          //!< number of elements within queue
   pthread_mutex_t mx;
   int cpipe[2];
} queue_t;


enum {MSG_NEW, MSG_INPROG, MSG_READY};


void queue_destroy(queue_t *q);
int queue_init(queue_t *q);
int queue_lock(queue_t *q);
int queue_unlock(queue_t *q);
int queue_wait(queue_t *q);
int queue_signal_val(queue_t *q, char c);
int queue_signal(queue_t *q);
int queue_is_dup(queue_t *q, const command_t *cmd, int(*cmp_func)(const command_t*, const command_t*));
int queue_data_nomx(queue_t *q, command_t cmd);
int queue_data(queue_t *q, command_t cmd);
int dequeue_data(queue_t *q, command_t *cmd);
int queue_remove(queue_t *, int );


#endif

