/* Copyright 2014 Bernhard R. Fischer.
 *
 * This file is part of DChat.
 *
 * DChat is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * DChat is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DChat. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DCHAT_H
#define DCHAT_H

#include <sys/socket.h>
#include <netinet/in.h>
#include <pthread.h>

#include "cqueue.h"
#include "contacts.h"

#define DEF_PORT 7777
#define FRAME_BUF_LEN 4096
#define MAX_CONTENT_LENGTH 1024
#define MAX_LINE_LENGTH 1024
#define MAX_IP 10


typedef struct dchat_conf
{
   contact_list_t cl;         //!< contact list

   int acpt_fd;               //!< listening socket
   uint16_t port;             //!< local listening port number
   int in_fd, out_fd;         //!< console input and output
   queue_t queue;
   int cl_change[2];          //!< pipe to signal wait loop from connector

   struct sockaddr_storage socks_addr;    //!< address of SOCKS server (Tor)
   const char *hostname;                  //!< local hostname

   struct sockaddr_storage addr[MAX_IP];  //!< list of own IP addresses
   int addr_cnt;                          //!< number of IPs in list
   pthread_mutex_t mx;                    //!< mutex to lock addr[]
} dchat_conf_t;


// list of command line commands
enum {CMD_E_SYNTAX = -1, CMD_TEXT, CMD_UNKNOWN, CMD_EMPTY, CMD_CONNECT, CMD_LIST, CMD_HELP, CMD_FRAG, CMD_DEBUG, CMD_CLOSE, CMD_DISCOVER, CMD_ADDRESSES};


#endif

